pub struct Sequencer<S: Stream> {
inner: S,
timer: Sleep,
buffer: BinaryHeap<Reverse<S::Item>>,
next_id: FrameId,
last_emitted: Instant,
max_wait: Duration,
state: State,
}Expand description
Sequencer is an adaptor for streams, that yield elements that have a natural ordering and
can be compared with FrameId and puts them in the correct sequence starting with
FrameId equal to 1.
Sequencer internally maintains a FrameId to be yielded next, polls the underlying stream
and yields elements only when they match the next FrameId to be yielded, incrementing the
value on each yield.
The Sequencer takes to arguments: max_wait and capacity:
The max_wait indicates the maximum amount of time to wait for a certain FrameId to
be yielded from the underlying stream.
If this does not happen, the Segmenter yields an error,
indicating that the given frame was discarded.
The capacity parameter sets the maximum number of buffered elements inside the Sequencer.
If this value is reached, the Sequencer will stop polling the underlying stream, waiting for the
next element to expire.
By definition, Sequencer is a fallible stream, yielding either Ok(Item), Err(SessionError::FrameDiscarded)
or Ok(None) when the underlying stream is closed and no more elements can be yielded.
Use SequencerExt methods to turn a stream into a sequenced stream.
Fields
inner: Stimer: Sleepbuffer: BinaryHeap<Reverse<S::Item>>next_id: FrameIdlast_emitted: Instantmax_wait: Durationstate: StateImplementations